@@ -5,7 +5,7 @@ use warnings;
 use Fennec::Test;
 use Fennec::Util qw/inject_sub require_module/;
 use Carp qw/croak carp/;
-our $VERSION = '2.000_001';
+our $VERSION = '2.001';
 
 sub defaults {
     (
@@ -24,6 +24,18 @@ sub defaults {
     );
 }
 
+sub _setup_class {
+    my $class = shift;
+    my ( $runner, $importer, $load ) = @_;
+    return unless $load;
+
+    require_module $load;
+
+    no strict 'refs';
+    *{"$importer\::CLASS"} = \$load;
+    *{"$importer\::class"} = sub { $load };
+}
+
 sub import {
     my $class    = shift;
     my $importer = caller;
@@ -42,6 +54,7 @@ sub import {
 
     my $meta = $class->_init_meta( $importer, %params );
 
+    $class->_setup_class( $runner, $importer, $params{class} );
     $class->_process_deps( $runner, $params{skip_without} );
     $class->_set_isa( $importer, 'Fennec::Test', $meta->base );
     $class->_load_utils( $importer, %params );
@@ -62,8 +75,6 @@ sub init {
     my $meta     = $params{meta};
 
     my $wfmeta = $importer->TEST_WORKFLOW;
-    Fennec::Runner->new->collector->update_wfmeta($wfmeta);
-
     $wfmeta->test_sort( $meta->test_sort )
         if $meta->test_sort;
 
@@ -84,7 +95,7 @@ sub _get_runner {
 
     if ($runner_init) {
         my $runner = $runner_class->new;
-        croak "Runner is already initialized, but it is not a $runner_class"
+        carp "Runner is already initialized, but it is not a $runner_class"
             unless $runner->isa($runner_class);
 
         carp "Runner is already initialized, ignoring 'runner_params'"
@@ -450,11 +461,39 @@ L<Test::Exception> - Test code that throws exceptions
 
 Load the specified module and make it the base class for your test class.
 
+=item class => 'What::To::Test'
+
+Used to specify the name of the package your test file is validating. When this
+parameter is specified 3 things are done for you: The class is automatically
+loaded, the $CLASS variable is imported and contains the module name, and the
+class() subroutine is defined and returns the name.
+
+    use Fennec class => 'Foo::Bar';
+
+    ok( $INC{'Foo/Bar.pm'}, "Loaded 'Foo::Bar'" );
+    is( $CLASS, 'Foo::Bar', "We have \$CLASS" );
+    is( class(), 'Foo::Bar', "We have class()" );
+
+    tests method => sub {
+        my $self = shift;
+        is( $self->class(), 'Foo::Bar', "We have class() method" );
+    };
+
+    done_testing;
+
 =item parallel => $PROC_LIMIT
 
 How many test blocks can be run in parallel. Default is 3. Set to 1 to fork for
 each test, but only run one at a time. Set to 0 to prevent forking.
 
+=item collector_class => 'Fennec::Collector::TB::TempFiles'
+
+Specify which collector to use. Defaults to a Test::Builder based collector
+that uses temp files to funnel tests from child procs to the parent.
+
+You generally won't need to specify this, unless you use a test infrastructure
+that is neither TAP nore Test::Builder based.
+
 =item runner_class => 'Fennec::Runner'
 
 Specify the runner class. You probably don't need this.
@@ -477,6 +516,14 @@ Code block accepts a list of Test::Workflow::Test objects.
 
 Load these modules instead of the default list.
 
+If you need to specify import arguments for any specific util class, you can
+use the class name as the key with an arrayref containing the arguments.
+
+    use Fennec(
+        utils          => [ 'Some::Module' ],
+        'Some::Module' => [ arg => $val, ... ],
+    );
+
 =item with_tests => [ 'Reusable::Tests', 'Common::Tests' ]
 
 Load these modules that have reusable tests. Reusable tests are tests that are
